% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/edge.R
\name{edge}
\alias{edge}
\title{Efficient Estimation of Bid-Ask Spreads from Open, High, Low, and Close Prices}
\usage{
edge(open, high, low, close, sign = FALSE)
}
\arguments{
\item{open}{numeric vector of open prices.}

\item{high}{numeric vector of high prices.}

\item{low}{numeric vector of low prices.}

\item{close}{numeric vector of close prices.}

\item{sign}{whether to return signed estimates.}
}
\value{
The spread estimate. A value of 0.01 corresponds to a spread of 1\%.
}
\description{
Implements the efficient estimator of bid-ask spreads from open, high, low, 
and close prices described in Ardia, Guidotti, & Kroencke (JFE, 2024):
\doi{10.1016/j.jfineco.2024.103916}
}
\details{
Prices must be sorted in ascending order of the timestamp.
}
\examples{
# reduce number of threads to pass CRAN checks (you can ignore this)
data.table::setDTthreads(1)

# simulate open, high, low, and close prices with spread 1\%
x <- sim(n = 1000, spread = 0.01)

# estimate the spread
edge(x$Open, x$High, x$Low, x$Close)

}
\references{
Ardia, D., Guidotti, E., Kroencke, T.A. (2024). Efficient Estimation of Bid-Ask Spreads from Open, High, Low, and Close Prices. Journal of Financial Economics, 161, 103916. 
\doi{10.1016/j.jfineco.2024.103916}
}
